﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 교차점 함수
        /// </summary>
        private CrossPoints crossPoints;

        /// <summary>
        /// 라인 1 시리즈
        /// </summary>
        private Line line1;

        /// <summary>
        /// 라인 2 시리즈
        /// </summary>
        private Line line2;

        /// <summary>
        /// 라인 3 시리즈
        /// </summary>
        private Line line3;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 교차점 함수를 생성한다.

            this.crossPoints = new CrossPoints();

            #endregion
            #region 라인 1 시리즈를 생성한다.

            this.line1 = new Line();

            this.line1.Title       = "line1";
            this.line1.Brush.Color = Color.FromArgb(200, 230, 90);
            this.line1.Color       = Color.FromArgb(200, 230, 90);

            #endregion
            #region 라인 2 시리즈를 생성한다.

            this.line2 = new Line();

            this.line2.Title       = "line2";
            this.line2.Brush.Color = Color.FromArgb(90, 150, 220);
            this.line2.Color       = Color.FromArgb(90, 150, 220);

            #endregion
            #region 라인 3 시리즈를 생성한다.

            this.line3 = new Line();

            this.line3.Title               = "line3";
            this.line3.Brush.Color         = Color.FromArgb(230, 90, 40);
            this.line3.Color               = Color.FromArgb(230, 90, 40);
            this.line3.Pointer.Brush.Color = Color.Yellow;
            this.line3.Pointer.HorizSize   = 2;
            this.line3.Pointer.VertSize    = 2;
            this.line3.Pointer.Visible     = true;
            this.line3.DataSource          = new object[] { this.line1, this.line2 };
            this.line3.Function            = this.crossPoints;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Axes.Left.MaximumOffset   = 3;
            this.tChart.Axes.Left.MinimumOffset   = 3;
            this.tChart.Axes.Bottom.MaximumOffset = 3;
            this.tChart.Axes.Bottom.MinimumOffset = 3;

            this.tChart.Series.Add(this.line1);
            this.tChart.Series.Add(this.line2);
            this.tChart.Series.Add(this.line3);

            #endregion

            for(double x = -5; x < 5; x += 0.2)
            {
                this.line1.Add(x, Math.Sin(Math.PI / 2 * x)       );
                this.line2.Add(x, Math.Sin(Math.PI / 6 * x) - 0.25);
            }

            this.line3.CheckDataSource();

            this.showCrosspointCheckBox.CheckedChanged += showCrosspointCheckBox_CheckedChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 교차점 표시 체크 박스 체크 변경시 처리하기 - showCrosspointCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 교차점 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showCrosspointCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.line3.Active = this.showCrosspointCheckBox.Checked;
        }

        #endregion
    }
}